@@ -125,6 +125,14 @@ class FilteredLedger:
         filter: str | None = None,  # noqa: A002
         time: str | None = None,
     ) -> None:
+        """Create a filtered view of a ledger.
+
+        Args:
+            ledger: The ledger to filter.
+            account: The account filter.
+            filter: The advanced filter.
+            time: The time filter.
+        """
         self.ledger = ledger
         self.date_range: DateRange | None = None
         self._pages: (
@@ -196,7 +204,11 @@ class FilteredLedger:
         return tree
 
     def interval_ranges(self, interval: Interval) -> Sequence[DateRange]:
-        """Yield date ranges corresponding to interval boundaries."""
+        """Yield date ranges corresponding to interval boundaries.
+
+        Args:
+            interval: The interval to yield ranges for.
+        """
         if not self._date_first or not self._date_last:
             return []
         complete = not self.date_range
@@ -205,7 +217,12 @@ class FilteredLedger:
         )
 
     def prices(self, base: str, quote: str) -> Sequence[tuple[date, Decimal]]:
-        """List all prices."""
+        """List all prices for a pair of commodities.
+
+        Args:
+            base: The price base.
+            quote: The price quote.
+        """
         all_prices = self.ledger.prices.get_all_prices((base, quote))
         if all_prices is None:
             return []
@@ -276,11 +293,7 @@ class FilteredLedger:
 
 
 class FavaLedger:
-    """Create an interface for a Beancount ledger.
-
-    Arguments:
-        path: Path to the main Beancount file.
-    """
+    """Interface for a Beancount ledger."""
 
     __slots__ = (
         "_is_encrypted",
@@ -330,45 +343,63 @@ class FavaLedger:
     #: Dict of list of all (unfiltered) entries by type.
     all_entries_by_type: EntriesByType
 
+    #: A :class:`.AccountDict` module - details about the accounts.
+    accounts: AccountDict
+
+    #: An :class:`AttributesModule` instance.
+    attributes: AttributesModule
+
+    #: A :class:`.BudgetModule` instance.
+    budgets: BudgetModule
+
+    #: A :class:`.ChartModule` instance.
+    charts: ChartModule
+
+    #: A :class:`.CommoditiesModule` instance.
+    commodities: CommoditiesModule
+
+    #: A :class:`.ExtensionModule` instance.
+    extensions: ExtensionModule
+
+    #: A :class:`.FileModule` instance.
+    file: FileModule
+
+    #: A :class:`.DecimalFormatModule` instance.
+    format_decimal: DecimalFormatModule
+
+    #: A :class:`.IngestModule` instance.
+    ingest: IngestModule
+
+    #: A :class:`.FavaMisc` instance.
+    misc: FavaMisc
+
+    #: A :class:`.QueryShell` instance.
+    query_shell: QueryShell
+
     def __init__(self, path: str, *, poll_watcher: bool = False) -> None:
+        """Create an interface for a Beancount ledger.
+
+        Arguments:
+            path: Path to the main Beancount file.
+            poll_watcher: Whether to use the polling file watcher.
+        """
         #: The path to the main Beancount file.
         self.beancount_file_path = path
         self._is_encrypted = is_encrypted_file(path)
         self.get_filtered = lru_cache(maxsize=16)(self._get_filtered)
         self.get_entry = lru_cache(maxsize=16)(self._get_entry)
 
-        #: An :class:`AttributesModule` instance.
-        self.attributes = AttributesModule(self)
-
-        #: A :class:`.BudgetModule` instance.
-        self.budgets = BudgetModule(self)
-
-        #: A :class:`.ChartModule` instance.
-        self.charts = ChartModule(self)
-
-        #: A :class:`.CommoditiesModule` instance.
-        self.commodities = CommoditiesModule(self)
-
-        #: A :class:`.ExtensionModule` instance.
-        self.extensions = ExtensionModule(self)
-
-        #: A :class:`.FileModule` instance.
-        self.file = FileModule(self)
-
-        #: A :class:`.IngestModule` instance.
-        self.ingest = IngestModule(self)
-
-        #: A :class:`.FavaMisc` instance.
-        self.misc = FavaMisc(self)
-
-        #: A :class:`.DecimalFormatModule` instance.
-        self.format_decimal = DecimalFormatModule(self)
-
-        #: A :class:`.QueryShell` instance.
-        self.query_shell = QueryShell(self)
-
-        #: A :class:`.AccountDict` module - details about the accounts.
         self.accounts = AccountDict(self)
+        self.attributes = AttributesModule(self)
+        self.budgets = BudgetModule(self)
+        self.charts = ChartModule(self)
+        self.commodities = CommoditiesModule(self)
+        self.extensions = ExtensionModule(self)
+        self.file = FileModule(self)
+        self.format_decimal = DecimalFormatModule(self)
+        self.ingest = IngestModule(self)
+        self.misc = FavaMisc(self)
+        self.query_shell = QueryShell(self)
 
         self.watcher = WatchfilesWatcher() if not poll_watcher else Watcher()
 
@@ -416,12 +447,15 @@ class FavaLedger:
         filter: str | None = None,  # noqa: A002
         time: str | None = None,
     ) -> FilteredLedger:
-        """Filter the ledger."""
+        """Filter the ledger.
+
+        Args:
+            account: The account filter.
+            filter: The advanced filter.
+            time: The time filter.
+        """
         return FilteredLedger(
-            ledger=self,
-            account=account,
-            filter=filter,
-            time=time,
+            ledger=self, account=account, filter=filter, time=time
         )
 
     @property
