@@ -99,7 +99,7 @@ class FavaOptions:
     default_page: str = "income_statement/"
     fiscal_year_end: FiscalYearEnd = END_OF_YEAR
     import_config: str | None = None
-    import_dirs: tuple[str, ...] = ()
+    import_dirs: Sequence[str] = field(default_factory=list)
     indent: int = 2
     insert_entry: Sequence[InsertEntryOption] = field(default_factory=list)
     invert_gains_losses_colors: bool = False
@@ -139,6 +139,11 @@ class FavaOptions:
             raise InvalidFiscalYearEndOptionError(value)
         self.fiscal_year_end = fye
 
+    def set_import_dirs(self, value: str) -> None:
+        """Add an import directory."""
+        # It's typed as Sequence so that it's not externally mutated
+        self.import_dirs.append(value)  # type: ignore[attr-defined]
+
     def set_insert_entry(
         self, value: str, date: datetime.date, filename: str, lineno: int
     ) -> None:
@@ -181,7 +186,10 @@ TUPLE_OPTS = {f.name for f in _fields if f.type.startswith("tuple[str,")}
 STR_OPTS = {f.name for f in _fields if f.type.startswith("str")}
 
 
-def parse_option_custom_entry(entry: Custom, options: FavaOptions) -> None:
+def parse_option_custom_entry(  # noqa: PLR0912
+    entry: Custom,
+    options: FavaOptions,
+) -> None:
     """Parse a single custom fava-option entry and set option accordingly."""
     key = str(entry.values[0].value).replace("-", "_")
     if key not in All_OPTS:
@@ -198,6 +206,8 @@ def parse_option_custom_entry(entry: Custom, options: FavaOptions) -> None:
         options.set_default_file(value, filename)
     elif key == "fiscal_year_end":
         options.set_fiscal_year_end(value)
+    elif key == "import_dirs":
+        options.set_import_dirs(value)
     elif key == "insert_entry":
         options.set_insert_entry(value, entry.date, filename, lineno)
     elif key == "language":
